@@ -1,3 +1,4 @@
+from .exception import PipelineException
 from .message import Message
 from .tap import DestinationTap, SourceTap, SourceOf, DestinationOf
 from .worker import Generator, Processor, Splitter
@@ -5,6 +6,7 @@ from .utils import parse_kind
 
 
 __all__ = [
+    'PipelineException',
     'SourceOf',
     'DestinationOf',
     'SourceTap',
