@@ -1,8 +1,9 @@
 #!/usr/bin/env python
-import argparse
+import codecs
 import json
 import logging
 import os
+import sys
 from abc import ABC, abstractmethod
 
 import pulsar
@@ -165,7 +166,10 @@ class FileSource(SourceTap):
 
     def __init__(self, config, logger=logger):
         super().__init__(config, logger)
-        self.infile = config.infile
+        if config.infile == '-':
+            self.infile = codecs.getreader('utf-8')(sys.stdin)
+        else:
+            self.infile = open(config.infile, 'r')
         self.repeat = config.repeat
 
     def __repr__(self):
@@ -174,7 +178,7 @@ class FileSource(SourceTap):
     @classmethod
     def add_arguments(cls, parser):
         super().add_arguments(parser)
-        parser.add_argument('--infile', type=argparse.FileType('r'), required=True,
+        parser.add_argument('--infile', type=str, required=True,
                             help='input file containing one message in JSON format per line')
         parser.add_argument('--repeat', type=int, default=1,
                             help='repeat input N times')
@@ -203,7 +207,10 @@ class FileDestination(DestinationTap):
 
     def __init__(self, config, logger=logger):
         super().__init__(config, logger)
-        self.outFile = config.outfile
+        if config.outfile == '-':
+            self.outFile = codecs.getwriter('utf-8')(sys.stdout)
+        else:
+            self.outFile = open(config.outfile, 'w')
 
     def __repr__(self):
         return 'FileDestination("{}")'.format(self.outFile.name)
@@ -211,7 +218,7 @@ class FileDestination(DestinationTap):
     @classmethod
     def add_arguments(cls, parser):
         super().add_arguments(parser)
-        parser.add_argument('--outfile', type=argparse.FileType('w'), required=True,
+        parser.add_argument('--outfile', type=str, required=True,
                             help='output json file')
 
     def write(self, message):
@@ -411,7 +418,12 @@ class PulsarSource(SourceTap):
             self.namespace,
             self.topic
         )
-        self.consumer = self.client.subscribe(self.name, self.subscription)
+        self.consumer = self.client.subscribe(
+            self.name,
+            self.subscription,
+            receiver_queue_size=1,
+            consumer_type=pulsar.ConsumerType.Shared,
+        )
         self.last_msg = None
 
     def __repr__(self):
